survival_sex_rel: Survival rate based on Sex.

Description Usage Arguments Value Examples

View source: R/survival_sex_rel.R

Description

This function analyses the relationship between Survival rate and sex of the passengers.

Usage

1

Arguments

df:

The titanic train data set which we imported and converted to dataframe.

sub_sex

: subset which contains just the sex and survival rate of passenger

fem_total

:total females in the ship

male_total

:total males in the ship

sur_sex

:subset with only survived passengers

female_survived

: total female survived

male_survived

: total male survived

mf_total:

total analysis

plot_sex

: graphical representation of the relationship

Value

sex_rel_ans : returns the analysis and also the graphical representation.

Examples

1

unimi-dse/a2b3bab6 documentation built on Feb. 22, 2020, 5:43 a.m.